==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/igr-rate-of-change-and-momentum-indicator.js <==
import { __extends } from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { RateOfChangeAndMomentumIndicator } from "./RateOfChangeAndMomentumIndicator";
/**
 * Represents a IgxDataChartComponent Rate of Change and Momentum indicator series.
 * Default required members: Close
*
* `IgrRateOfChangeAndMomentumIndicator` class represents a Rate of Change and Momentum indicator series for the IgxDataChartComponent.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Year" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrRateOfChangeAndMomentumIndicator
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
* 		openMemberPath="Open"
* 		volumeMemberPath="Volume"
*         highMemberPath="High"
*         lowMemberPath="Low" />
*  </IgrDataChart>
* ```
*
* ```ts
* let series = new IgrRateOfChangeAndMomentumIndicator({name :"series"});
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
var IgrRateOfChangeAndMomentumIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRateOfChangeAndMomentumIndicator, _super);
    function IgrRateOfChangeAndMomentumIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrRateOfChangeAndMomentumIndicator.prototype.createImplementation = function () {
        return new RateOfChangeAndMomentumIndicator();
    };
    Object.defineProperty(IgrRateOfChangeAndMomentumIndicator.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRateOfChangeAndMomentumIndicator.prototype, "period", {
        /**
         * Gets or sets the moving average period for the current AverageTrueRangeSeries object.
         * The typical, and initial, value for AverageTrueRange periods is 14.
        *
        * You can use the `period` property for the current AverageTrueRangeSeries object.
        *
        * The typical, and initial, value for AverageTrueRange periods is 14.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *     <IgrCategoryXAxis name="xAxis" label="Year" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *     <IgrRateOfChangeAndMomentumIndicator
        *         name="series1"
        *         xAxisName="xAxis"
        *         yAxisName="yAxis"
        * 		openMemberPath="Open"
        * 		volumeMemberPath="Volume"
        *         highMemberPath="High"
        *         lowMemberPath="Low"
        * 		period=30 />
        *  </IgrDataChart>
        * ```
        *
        * ```ts
        * this.series.period = 30;
        * ```
        */
        get: function () {
            return this.i.u6;
        },
        set: function (v) {
            this.i.u6 = +v;
        },
        enumerable: false,
        configurable: true
    });
    return IgrRateOfChangeAndMomentumIndicator;
}(IgrStrategyBasedIndicator));
export { IgrRateOfChangeAndMomentumIndicator };

==> igniteui-react-charts-18.2.0.tgz: package/esm5/lib/igr-rate-of-change-and-momentum-indicator.js <==
import { __extends } from "tslib";
import { IgrStrategyBasedIndicator } from "./igr-strategy-based-indicator";
import { RateOfChangeAndMomentumIndicator } from "./RateOfChangeAndMomentumIndicator";
/**
 * Represents a IgxDataChartComponent Rate of Change and Momentum indicator series.
 * Default required members: Close
*
* `RateOfChangeAndMomentumIndicator` class represents a Rate of Change and Momentum indicator series for the IgxDataChartComponent.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Year" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrRateOfChangeAndMomentumIndicator
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
* 		openMemberPath="Open"
* 		volumeMemberPath="Volume"
*         highMemberPath="High"
*         lowMemberPath="Low" />
*  </IgrDataChart>
* ```
*
* ```ts
* let series = new IgrRateOfChangeAndMomentumIndicator({name :"series"});
* series.xAxis = this.xAxis;
* series.yAxis = this.yAxis;
* series.openMemberPath = "open";
* series.highMemberPath = "high";
* series.lowMemberPath = "low";
* series.closeMemberPath = "close";
* this.chart.series.add(series);
* ```
*/
var IgrRateOfChangeAndMomentumIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRateOfChangeAndMomentumIndicator, _super);
    function IgrRateOfChangeAndMomentumIndicator(props) {
        return _super.call(this, props) || this;
    }
    IgrRateOfChangeAndMomentumIndicator.prototype.createImplementation = function () {
        return new RateOfChangeAndMomentumIndicator();
    };
    Object.defineProperty(IgrRateOfChangeAndMomentumIndicator.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRateOfChangeAndMomentumIndicator.prototype, "period", {
        /**
         * Gets or sets the moving average period for the current AverageTrueRangeSeries object.
         * The typical, and initial, value for AverageTrueRange periods is 14.
        *
        * You can use the `period` property for the current AverageTrueRangeSeries object.
        *
        * The typical, and initial, value for AverageTrueRange periods is 14.
        *
        * ```ts
        * <IgrDataChart
        *     dataSource={this.state.dataSource}
        *     width="700px"
        *     height="500px">
        *
        *     <IgrCategoryXAxis name="xAxis" label="Year" />
        *     <IgrNumericYAxis  name="yAxis" />
        *
        *     <IgrRateOfChangeAndMomentumIndicator
        *         name="series1"
        *         xAxisName="xAxis"
        *         yAxisName="yAxis"
        * 		openMemberPath="Open"
        * 		volumeMemberPath="Volume"
        *         highMemberPath="High"
        *         lowMemberPath="Low"
        * 		period=30 />
        *  </IgrDataChart>
        * ```
        *
        * ```ts
        * this.series.period = 30;
        * ```
        */
        get: function () {
            return this.i.va;
        },
        set: function (v) {
            this.i.va = +v;
        },
        enumerable: false,
        configurable: true
    });
    return IgrRateOfChangeAndMomentumIndicator;
}(IgrStrategyBasedIndicator));
export { IgrRateOfChangeAndMomentumIndicator };
